import 'package:flutter/material.dart';
import 'package:nav/nav.dart';
import 'package:nav/route/custom_page_route_builder.dart';

class SlideFromLeftRouteBuilder<T> extends CustomPageRouteBuilder<T> {
  final Widget widget;

  SlideFromLeftRouteBuilder(this.widget,
      {int durationMs = Nav.defaultDurationMs})
      : super(
            pageBuilder: (BuildContext context, Animation<double> animation,
                Animation<double> secondaryAnimation) {
              return widget;
            },
            transitionDuration: Duration(milliseconds: durationMs),
            transitionsBuilder: (BuildContext context,
                Animation<double> animation,
                Animation<double> secondaryAnimation,
                Widget child) {
              return SlideTransition(
                position: Tween<Offset>(
                  begin: const Offset(-1.0, 0.0),
                  end: Offset.zero,
                ).animate(animation),
                child: child,
              );
            });
}

class SlideFromRightRouteBuilder<T> extends CustomPageRouteBuilder<T> {
  final Widget widget;

  SlideFromRightRouteBuilder(this.widget,
      {int durationMs = Nav.defaultDurationMs})
      : super(
            pageBuilder: (BuildContext context, Animation<double> animation,
                Animation<double> secondaryAnimation) {
              return widget;
            },
            transitionDuration: Duration(milliseconds: durationMs),
            transitionsBuilder: (BuildContext context,
                Animation<double> animation,
                Animation<double> secondaryAnimation,
                Widget child) {
              return SlideTransition(
                position: Tween<Offset>(
                  begin: const Offset(1.0, 0.0),
                  end: Offset.zero,
                ).animate(animation),
                child: child,
              );
            });
}

class SlideFromBottomRoute<T> extends CustomPageRouteBuilder<T> {
  final Widget widget;

  SlideFromBottomRoute(this.widget, {int durationMs = Nav.defaultDurationMs})
      : super(
            pageBuilder: (BuildContext context, Animation<double> animation,
                Animation<double> secondaryAnimation) {
              return widget;
            },
            transitionDuration: Duration(milliseconds: durationMs),
            transitionsBuilder: (BuildContext context,
                Animation<double> animation,
                Animation<double> secondaryAnimation,
                Widget child) {
              return SlideTransition(
                position: Tween<Offset>(
                  begin: const Offset(0.0, 1.0),
                  end: Offset.zero,
                ).animate(animation),
                child: child,
              );
            });
}

class SlideFromTopRoute<T> extends CustomPageRouteBuilder<T> {
  final Widget widget;

  SlideFromTopRoute(this.widget, {int durationMs = Nav.defaultDurationMs})
      : super(
            pageBuilder: (BuildContext context, Animation<double> animation,
                Animation<double> secondaryAnimation) {
              return widget;
            },
            transitionDuration: Duration(milliseconds: durationMs),
            transitionsBuilder: (BuildContext context,
                Animation<double> animation,
                Animation<double> secondaryAnimation,
                Widget child) {
              return SlideTransition(
                position: Tween<Offset>(
                  begin: const Offset(0.0, -1.0),
                  end: Offset.zero,
                ).animate(animation),
                child: child,
              );
            });
}
